summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/render_messages.h')
-rw-r--r--chrome/common/render_messages.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h
index 57cdcc8..96ffd631 100644
--- a/chrome/common/render_messages.h
+++ b/chrome/common/render_messages.h
@@ -159,12 +159,17 @@ struct ViewHostMsg_PaintRect_Flags {
};
struct ViewHostMsg_PaintRect_Params {
// The bitmap to be painted into the rect given by bitmap_rect.
TransportDIB::Id bitmap;
- // The position and size of the bitmap.
+ // The position and size of the the bitmap relative to the view port.
gfx::Rect bitmap_rect;
+ // The position and size of the rects where the bitmap has data to be
+ // painted to the view. An empty vector means that the whole bitmap has
+ // data to be painted to the view.
+ std::vector<gfx::Rect> paint_rects;
+
// The size of the RenderView when this message was generated. This is
// included so the host knows how large the view is from the perspective of
// the renderer process. This is necessary in case a resize operation is in
@@ -860,6 +865,7 @@ struct ParamTraits<ViewHostMsg_PaintRect_Params> {
static void Write(Message* m, const param_type& p) {
WriteParam(m, p.bitmap);
WriteParam(m, p.bitmap_rect);
+ WriteParam(m, p.paint_rects);
WriteParam(m, p.view_size);
WriteParam(m, p.plugin_window_moves);
WriteParam(m, p.flags);
@@ -868,6 +874,7 @@ struct ParamTraits<ViewHostMsg_PaintRect_Params> {
return
ReadParam(m, iter, &p->bitmap) &&
ReadParam(m, iter, &p->bitmap_rect) &&
+ ReadParam(m, iter, &p->paint_rects) &&
ReadParam(m, iter, &p->view_size) &&
ReadParam(m, iter, &p->plugin_window_moves) &&
ReadParam(m, iter, &p->flags);
@@ -878,6 +885,8 @@ struct ParamTraits<ViewHostMsg_PaintRect_Params> {
l->append(L", ");
LogParam(p.bitmap_rect, l);
l->append(L", ");
+ LogParam(p.paint_rects, l);
+ l->append(L", ");
LogParam(p.view_size, l);
l->append(L", ");
LogParam(p.plugin_window_moves, l);
@@ -159,12 +159,17 @@ struct ViewHostMsg_PaintRect_Flags {
};
struct ViewHostMsg_PaintRect_Params {
- // The bitmap to be painted into the rect given by bitmap_rect.
+ // The bitmap to be painted into the rects given by paint_rects.
TransportDIB::Id bitmap;